@@ -1,5 +1,5 @@
 module m_ncps
-  use m_ncps_froyen_ps_t, only: froyen_ps_t, pseudo_init_constant
+  use m_ncps_froyen_ps_t, only: froyen_ps_t, pseudo_init_constant, pseudo_reset
   use m_ncps_translators, only: ncps_psml2froyen
   use m_ncps_writers, only: pseudo_write_formatted, pseudo_header_print
   use m_ncps_reader, only: pseudo_read
