@@ -16,18 +16,18 @@ C     in the format for Xcrysden
       write (io2,212) iev,freq(iev)
       write (io2,'(A,i5)') 'ANIMSTEPS',nsteps
       if (nsteps.le.0) return
-C       write (io2,'(A,i5)') 'CRYSTAL'
-C       write (io2,'(A)') 'PRIMVEC'
-C       do ii=1,3
-C         write (io2,'(3f16.9)') (cc_ang(ii,jj),jj=1,3)
-C       enddo
+      write (io2,'(A,i5)') 'CRYSTAL'
+      write (io2,'(A)') 'PRIMVEC'
+      do ii=1,3
+         write (io2,'(3f16.9)') (cc_ang(jj,ii),jj=1,3)
+      enddo
 C     assume fixed-cell animation, because we deal with phonons
       do istep=1,nsteps
         rewind is1
         write (io2,'(A,i5)') 'ATOMS',istep
         do ibox=1,nbox
-          read  (is1,'(i4,3f20.8)') iat, (coort(jj),jj=1,3)
-          write (io2,'(i4,3f12.7,2x,3f12.7)') iz(iat),
+          read  (is1,'(i9,3f20.8)') iat, (coort(jj),jj=1,3)
+          write (io2,'(i9,3f12.7,2x,3f12.7)') iz(iat),
      .                (coort(jj) +
      +                 sin(pi2*istep/nsteps) *
      *                 disp(jj,iat,iev),jj=1,3)
